<!-- wp:group {"tagName":"main","className":"site-content page-blank-canvas"} -->
<main id="primary" class="wp-block-group site-content page-blank-canvas">

	<!-- wp:post-content {"layout":{"inherit":true}} /-->

</main>
<!-- /wp:group -->