<?php
return array(
			'title'         => __( 'Welcome 2', 'alara' ),
			'categories'    => array( 'alara-welcome' ),
			'keywords'		=> array( 'text', 'paragraph', 'heading', 'button' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:paragraph {"align":"center","style":{"typography":{"textTransform":"uppercase"}},"fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size" style="text-transform:uppercase">Welcome to</p>
<!-- /wp:paragraph -->

<!-- wp:site-title {"level":2,"textAlign":"center","isLink":false,"fontSize":"gigantic"} /-->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Lorem ipsum dolor sit amet consectetur adipiscing elit magna tempus inceptos conubia eleifend interdum, ridiculus eget sem eu facilisis arcu convallis netus fermentum fames habitasse habitant metus ultrices massa nostra euismod.</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Curae montes faucibus ultricies proin laoreet blandit cubilia senectus morbi euismod, nisl urna interdum metus cras maecenas etiam odio sociosqu, vitae elementum quisque orci sodales sollicitudin at viverra ad.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center"}} -->
<div class="wp-block-buttons"><!-- wp:button {"style":{"border":{"radius":"50px"}},"className":"is-style-outline"} -->
<div class="wp-block-button is-style-outline"><a class="wp-block-button__link" style="border-radius:50px">Who we are</a></div>
<!-- /wp:button -->

<!-- wp:button {"backgroundColor":"foreground","style":{"border":{"radius":"50px"}}} -->
<div class="wp-block-button"><a class="wp-block-button__link has-foreground-background-color has-background" style="border-radius:50px">What we do</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->',
);
