@import '../../../../scss/mixins';

.wrapper {
  background: #fff;
  max-width: 620px;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.1);
  border-radius: 4px;
  margin-bottom: $gridSpacingNormal;
  padding: $gridSpacingNormal;
}
