/** For hiding video section notice */
#sub-accordion-section-header_image .customize-section-description-container .customize-section-title .customize-control-notifications-container{
    visibility: hidden;
    height: 0;    
}

.customize-control-description ul li{
	padding-left: 20px;
	position: relative;
	font-size: 15px;
	line-height: 20px;
}

.customize-control-description ul li:after{
    content: '';
    background-image: url('data:image/svg+xml;utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="%23111" d="M173.898 439.404l-166.4-166.4c-9.997-9.997-9.997-26.206 0-36.204l36.203-36.204c9.997-9.998 26.207-9.998 36.204 0L192 312.69 432.095 72.596c9.997-9.997 26.207-9.997 36.204 0l36.203 36.204c9.997 9.997 9.997 26.206 0 36.204l-294.4 294.401c-9.998 9.997-26.207 9.997-36.204-.001z"></path></svg>');
    background-repeat: no-repeat;
    background-position: center;
    width: 9px;
    height: 28px;
    position: absolute;
    top: 50%;
    left: 0;
    -webkit-transform: translateY(-50%);
    transform: translateY(-50%);
    transition: linear 0.2s;
}

#sub-accordion-section-theme_info .customize-control-title{
	font-size: 16px;
	margin-bottom: 10px;
}

#sub-accordion-section-sidebar-widgets-service .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-testimonial .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-contact .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-cta .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-about .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-about-team .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-about-testimonial .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-about-cta .customize-section-description{
    display: none;
}

#sub-accordion-section-sidebar-widgets-service-cta .customize-section-description{
    display: none;
}

/* For inter linking in customizer control */
.text-inner-link{
    text-decoration: underline;
     color: #0073aa;
 }
.text-inner-link:hover{
     color: #00a0d2;
     cursor: pointer;
}

.customize-control-radio-image .image label {
    margin-top: 10px;
}

.customize-control-radio-image .image label img {
    vertical-align: top;
    border: 1px solid #bbb;
}

#input_page_sidebar_layout, 
#input_post_sidebar_layout, 
#input_layout_style {
    display: flex;
    flex-wrap: wrap;
    margin-left: -5px;
    margin-right: -5px;
}

#input_page_sidebar_layout label, 
#input_post_sidebar_layout label, 
#input_layout_style label {
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    width: 50%;
    padding-left: 5px;
    padding-right: 5px;
}


/** For hiding video section notice */
#sub-accordion-section-header_image .customize-section-description-container .customize-section-title .customize-control-notifications-container{
    visibility: hidden;
    height: 0;    
}

/*User stick note*/
h3.sticky_title {  
  margin-top: 12px;
  margin-bottom: 11px;
}

span.sticky_info_row {
  display: block;
  line-height: 23px;
}

label.row-element {
  font-weight: bold;
}

label.row-element.more-detail{
  color: #ff0000;
}

.customize-text_editor{
    font-size: 16px;
    font-weight: bold;    
}

.customize-text_editor_desc a {
  background-color: #0089BD;
  padding: 4px;
  color: #fff;
  border-radius: 7px;
  margin: 2px 0;
  display: inline-block;
  transition:all ease 0.3s;
  -webkit-transition:all ease 0.3s;
  -moz-transition:all ease 0.3s;
}
.customize-text_editor_desc a:hover {
  background-color: #fff;
  color: #0089BD;
}
.customize-text_editor_desc .download-link{
  display: block;
}
.customize-text_editor_desc span {  
  padding: 2px;
  margin: 0;
  display: inline-block;
}

.customize-text_editor_desc .upgrade-pro{
  color: #FFF !important;
  font-size: 12px;
  line-height: 1;  
  text-align: center;
  width: 90%;
  margin-top: 10px;  
}

#accordion-section-theme_info{
    color: #0089BD;
}
.control-section-vandana-lite-pro-section .accordion-section-title .button {
    margin-top:  -4px;
    font-weight: 700;
    margin-left: 8px;
  background: #f89300;
  color: #fff;
  border-color: #f89300;
  padding: 0 20px 1px;
}

.control-section-vandana-lite-pro-section .accordion-section-title .button:hover,
.control-section-vandana-lite-pro-section .accordion-section-title .button:focus{
  background: #dc8200;
  border-color: #dc8200;
}

.rtl .control-section-vandana-lite-pro-section .accordion-section-title .button {
    margin-left:  0;
    margin-right: 8px;
}