<?php
define('ZITA_LOADER', ZITA_THEME_URI. "images/zita-loader.gif");
define('ZITA_MAINHEADER_LAYOUT_LEFT', ZITA_THEME_URI. "customizer/images/mnhdrleft.png");
define('ZITA_MAINHEADER_LAYOUT_CENTER', ZITA_THEME_URI. "customizer/images/mnhdrcenter.png");
define('ZITA_MAINHEADER_LAYOUT_RIGHT', ZITA_THEME_URI. "customizer/images/mnhdrright.png");
define('ZITA_MAINHEADER_LAYOUT_RIGHTPAN', ZITA_THEME_URI. "customizer/images/mnhdrrightpan.png");
define('ZITA_MAINHEADER_LAYOUT_LEFTPAN', ZITA_THEME_URI. "customizer/images/mnhdrleftpan.png");
define('ZITA_MAINHEADER_LAYOUT_FULL', ZITA_THEME_URI. "customizer/images/mnhdrfull.png");
define('ZITA_MAINHEADER_LAYOUT_MINBARLEFT', ZITA_THEME_URI. "customizer/images/left-min-bar.png");
define('ZITA_MAINHEADER_LAYOUT_MINBARRIGHT', ZITA_THEME_URI. "customizer/images/right-minbar.png");
define('ZITA_HEADER_LAYOUT_1', ZITA_THEME_URI. "customizer/images/header-layout-1.png");

define('ZITA_TOP_HEADER_LAYOUT_NONE', ZITA_THEME_URI. "customizer/images/top-header-none.png");
define('ZITA_TOP_HEADER_LAYOUT_1', ZITA_THEME_URI. "customizer/images/top-header-1.png");
define('ZITA_TOP_HEADER_LAYOUT_2', ZITA_THEME_URI. "customizer/images/top-header-2.png");
define('ZITA_TOP_HEADER_LAYOUT_3', ZITA_THEME_URI. "customizer/images/top-header-3.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_NONE', ZITA_THEME_URI. "customizer/images/widget-footer-none.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_1', ZITA_THEME_URI. "customizer/images/widget-footer-1.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_2', ZITA_THEME_URI. "customizer/images/widget-footer-2.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_3', ZITA_THEME_URI. "customizer/images/widget-footer-3.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_4', ZITA_THEME_URI. "customizer/images/widget-footer-4.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_5', ZITA_THEME_URI. "customizer/images/widget-footer-5.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_6', ZITA_THEME_URI. "customizer/images/widget-footer-6.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_7', ZITA_THEME_URI. "customizer/images/widget-footer-7.png");
define('ZITA_FOOTER_WIDGET_LAYOUT_8', ZITA_THEME_URI. "customizer/images/widget-footer-8.png");
define('ZITA_FOOTER_ABOVE_LAYOUT_1', ZITA_THEME_URI. "customizer/images/above-footer.png");
define('ZITA_FOOTER_ABOVE_LAYOUT_2', ZITA_THEME_URI. "customizer/images/above-footer-1.png");
define('ZITA_FOOTER_ABOVE_LAYOUT_3', ZITA_THEME_URI. "customizer/images/above-footer-2.png");
/**************************/
// blog & archive layout
/**************************/
define('ZITA_BLOG_ARCHIVE_LAYOUT_1', ZITA_THEME_URI. "customizer/images/blog-layout-1.png");
define('ZITA_BLOG_ARCHIVE_LAYOUT_2', ZITA_THEME_URI. "customizer/images/blog-layout-2.png");
define('ZITA_BLOG_ARCHIVE_LAYOUT_3', ZITA_THEME_URI. "customizer/images/blog-layout-3.png");
define('ZITA_BLOG_ARCHIVE_LAYOUT_4', ZITA_THEME_URI. "customizer/images/blog-layout-4.png");
/**************************/
// Color Scheme
/**************************/
define('ZITA_COLOR_SCHM_DRK', ZITA_THEME_URI. "customizer/images/dark-color-scheme.png");
define('ZITA_COLOR_SCHM_DEF', ZITA_THEME_URI. "customizer/images/default-color-scheme.png");