import palette from '../../_data/colors/palette.json';

export default {
	800: palette[ 'gray-lamp-post' ],
	700: palette[ 'gray-blue-planet' ],
	600: palette[ 'gray-sheffield' ],
	500: palette[ 'gray-special-delivery' ],
	400: palette[ 'gray-stone-golem' ],
	300: palette[ 'gray-hidden-creek' ],
	200: palette[ 'gray-anti-flash' ],
	100: palette[ 'gray-emptiness' ],
};
