<?php
return array(
			'title'         => __( 'Specifications 2', 'alara' ),
			'categories'    => array( 'alara-features' ),
			'keywords'		=> array( 'features', 'info', 'media', 'image' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:media-text {"align":"","mediaPosition":"right","mediaLink":"' . alara_pattern_content( 'image-camera-lens-2' ) . '","mediaType":"image","imageFill":false,"textColor":"foreground"} -->
<div class="wp-block-media-text has-media-on-the-right is-stacked-on-mobile has-foreground-color has-text-color"><figure class="wp-block-media-text__media"><img src="' . alara_pattern_content( 'image-camera-lens-2' ) . '" alt=""/></figure><div class="wp-block-media-text__content"><!-- wp:paragraph {"style":{"typography":{"lineHeight":"1"}},"textColor":"primary","fontSize":"small"} -->
<p class="has-primary-color has-text-color has-small-font-size" style="line-height:1"><em><strong>Product name introduction</strong></em></p>
<!-- /wp:paragraph -->

<!-- wp:heading {"style":{"typography":{"lineHeight":"1"}},"textColor":"foreground"} -->
<h2 class="has-foreground-color has-text-color" id="specification" style="line-height:1">Specifications</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"style":{"typography":{"lineHeight":"1"}},"fontSize":"small"} -->
<p class="has-small-font-size" style="line-height:1"><strong>Features:</strong></p>
<!-- /wp:paragraph -->

<!-- wp:list {"className":"is-style-line","fontSize":"small"} -->
<ul class="is-style-line has-small-font-size"><li>This is feature one</li><li>Item two included</li><li>Optional item three</li><li>Service four included</li><li>And finally, item five</li></ul>
<!-- /wp:list --></div></div>
<!-- /wp:media-text -->',
);
