<?php
return array(
			'title'         => __( 'Spacer', 'alara' ),
			'inserter'		=> false,
			'content'       => '<!-- wp:spacer {"height":64} -->
<div style="height:64px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->',
);
