<?php
return array(
			'title'         => __( 'Team 3', 'alara' ),
			'categories'    => array( 'alara-about' ),
			'keywords'		=> array( 'about', 'info', 'media', 'image' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:group {"align":"full","style":{"spacing":{"padding":{"top":"6em","bottom":"6em"}}},"backgroundColor":"foreground","layout":{"inherit":true}} -->
<div class="wp-block-group alignfull has-foreground-background-color has-background" style="padding-top:6em;padding-bottom:6em"><!-- wp:media-text {"mediaLink":"none","align":"","mediaType":"image","backgroundColor":"septenary","textColor":"secondary"} -->
<div class="wp-block-media-text is-stacked-on-mobile has-secondary-color has-septenary-background-color has-text-color has-background"><figure class="wp-block-media-text__media"><img src="' . alara_pattern_content( 'image-woman-1' ) . '" alt=""/></figure><div class="wp-block-media-text__content"><!-- wp:paragraph {"align":"center","placeholder":"Content…","textColor":"primary","className":"is-style-script","fontSize":"large"} -->
<p class="has-text-align-center is-style-script has-primary-color has-text-color has-large-font-size">Kelly Grayson</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","textColor":"tertiary"} -->
<p class="has-text-align-center has-tertiary-color has-text-color"><sub>-</sub> Design <sub>-</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size">Lorem ipsum dolor sit amet consectetur adipiscing elit duis nibh sodales lectus, fusce nunc tellus auctor aenean risus nullam.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:social-links {"iconColor":"octonary","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002doctonary)","size":"has-large-icon-size","align":"center","className":"is-style-logos-only","layout":{"type":"flex"}} -->
<ul class="wp-block-social-links aligncenter has-large-icon-size has-icon-color is-style-logos-only">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div></div>
<!-- /wp:media-text -->

<!-- wp:media-text {"mediaPosition":"right","mediaLink":"none","align":"","mediaType":"image","backgroundColor":"septenary","textColor":"secondary","className":"is-style-no-block-gap"} -->
<div class="wp-block-media-text has-media-on-the-right is-stacked-on-mobile is-style-no-block-gap has-secondary-color has-septenary-background-color has-text-color has-background"><figure class="wp-block-media-text__media"><img src="' . alara_pattern_content( 'image-woman-2' ) . '" alt=""/></figure><div class="wp-block-media-text__content"><!-- wp:paragraph {"align":"center","placeholder":"Content…","textColor":"primary","className":"is-style-script","fontSize":"huge"} -->
<p class="has-text-align-center is-style-script has-primary-color has-text-color has-huge-font-size">Alara Kitan</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","textColor":"tertiary"} -->
<p class="has-text-align-center has-tertiary-color has-text-color"><sub>-</sub> Marketing <sub>-</sub></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size">Lorem ipsum dolor sit amet consectetur adipiscing elit duis nibh sodales lectus, fusce nunc tellus auctor aenean risus nullam.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:social-links {"iconColor":"octonary","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002doctonary)","size":"has-large-icon-size","align":"center","className":"is-style-logos-only","layout":{"type":"flex"}} -->
<ul class="wp-block-social-links aligncenter has-large-icon-size has-icon-color is-style-logos-only">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div></div>
<!-- /wp:media-text --></div>
<!-- /wp:group -->',
);
