import type from '../../_data/typography/typography.json';

export default {
	base: type[ 'font-size-base' ],
	10: type[ 'font-size-10' ],
	11: type[ 'font-size-11' ],
	12: type[ 'font-size-12' ],
	13: type[ 'font-size-13' ],
	14: type[ 'font-size-14' ],
	15: type[ 'font-size-15' ],
	18: type[ 'font-size-18' ],
	20: type[ 'font-size-20' ],
	26: type[ 'font-size-26' ],
	30: type[ 'font-size-30' ],
	caption: type[ 'font-size-caption' ],
	micro: type[ 'font-size-micro' ],
};
