.wp-block-query-pagination-numbers a{
  text-decoration:underline;
}
.wp-block-query-pagination-numbers .page-numbers{
  margin-right:2px;
}
.wp-block-query-pagination-numbers .page-numbers:last-child{
  margin-right:0;
}