.customize-control-vandana-lite-toggle label {
    display: flex;
    flex-wrap: wrap; 
}
.customize-control-vandana-lite-toggle label .customize-control-title {
    width: calc(100% - 55px); 
}
.customize-control-vandana-lite-toggle label .description {
    order: 99; 
}
.customize-control-vandana-lite-toggle input[type="checkbox"] {
    display: none; 
}
.customize-control-vandana-lite-toggle .switch { 
    border: 1px solid rgba(0, 0, 0, 0.1);
    display: inline-block;
    width: 35px;
    height: 12px;
    border-radius: 8px;
    background: #ccc;
    vertical-align: middle;
    position: relative;
    cursor: pointer;
    user-select: none;
    transition: background 350ms ease; 
}
.customize-control-vandana-lite-toggle .switch:before, .customize-control-vandana-lite-toggle .switch:after {
    content: "";
    display: block;
    width: 20px;
    height: 20px;
    border-radius: 50%;
    position: absolute;
    top: 50%;
    left: -3px;
    transition: all 350ms cubic-bezier(0, 0.95, 0.38, 0.98), background 150ms ease; 
}
.customize-control-vandana-lite-toggle .switch:before {
    background: rgba(0, 0, 0, 0.2);
    transform: translate3d(0, -50%, 0) scale(0); 
}
.customize-control-vandana-lite-toggle .switch:after {
    background: #999;
    border: 1px solid rgba(0, 0, 0, 0.1);
    transform: translate3d(0, -50%, 0); 
}
.customize-control-vandana-lite-toggle .switch:active:before {
    transform: translate3d(0, -50%, 0) scale(3);
}
.customize-control-vandana-lite-toggle input:checked + .switch {
    background: rgba(52, 152, 222, 0.3); 
}
.customize-control-vandana-lite-toggle input:checked + .switch:before {
    background: rgba(52, 152, 222, 0.075);
    transform: translate3d(100%, -50%, 0) scale(1); 
}
.customize-control-vandana-lite-toggle input:checked + .switch:after {
    background: #3498DE;
    transform: translate3d(100%, -50%, 0); 
}
.customize-control-vandana-lite-toggle input:checked + .switch:active:before {
    background: rgba(52, 152, 222, 0.075);
    transform: translate3d(100%, -50%, 0) scale(3); 
}