.wrapper {
  display: flex;
  flex-direction: column;
}

.formWrapper {
  display: flex;
}

.inputWrapper {
  flex: 0 0 320px;
}

.buttonWrapper {
  margin-left: 10px;

  [dir='rtl'] & {
    margin-left: 0;
    margin-right: 10px;
  }
}

.instructions {
  margin: 0 0 12px;
  font-size: 12px;
}

.errors {
  margin: 12px 0 0;
  color: #f00;
}
