@import '../../../../scss/mixins';

.item {
  flex: 0 1 100%;
  padding: 0 1% 2%;
  margin: 0;
  min-width: 0;

  @include tabletOnly {
    flex: 0 1 50%;
  }

  @include desktop {
    &.widthTwenty {
      flex: 0 1 20%;
    }

    &.widthTwentyFive {
      flex: 0 1 25%;
    }

    &.widthThirtyThree {
      flex: 0 1 33.3333333%;
    }

    &.widthFourty {
      flex: 0 1 40%;
    }

    &.widthFifty {
      flex: 0 1 50%;
    }

    &.widthSixty {
      flex: 0 1 60%;
    }

    &.widthFull {
      flex: 0 1 100%;
    }
  }
}
