/*! elementor - v3.5.6 - 28-02-2022 */
"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["wp-audio"],{

/***/ "../assets/dev/js/frontend/handlers/wp-audio.js":
/*!******************************************************!*\
  !*** ../assets/dev/js/frontend/handlers/wp-audio.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

class WpAudio extends elementorModules.frontend.handlers.Base {
  onInit() {
    super.onInit();
    window.wp.mediaelement.initialize();
  }

}

exports["default"] = WpAudio;

/***/ })

}]);
//# sourceMappingURL=wp-audio.8d458e51b4543ed99c04.bundle.js.map