import palette from '../../_data/colors/palette.json';

export default {
	textMuted: palette[ 'gray-hidden-creek' ],
	disabled: palette[ 'gray-stone-golem' ],
	light: palette.white,
	dark: palette.black,
	info: palette[ 'cyan-ionized-air-glow' ],
	cta: palette[ 'red-rose-garnet' ],
	danger: palette[ 'red-carnelian' ],
	success: palette[ 'green-spandex' ],
	primary: palette[ 'green-spandex' ],
	warning: palette[ 'yellow-hot-sun' ],
};
