<?php
return array(
			'title'         => __( 'Reviews 2', 'alara' ),
			'categories'    => array( 'alara-reviews' ),
			'keywords'		=> array( 'feedback', 'testimonial' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:group {"backgroundColor":"secondary"} -->
<div class="wp-block-group has-secondary-background-color has-background"><!-- wp:group {"layout":{"type":"flex","allowOrientation":false,"justifyContent":"space-between"}} -->
<div class="wp-block-group"><!-- wp:heading -->
<h2 id="what-our-customers-say">What our customers say</h2>
<!-- /wp:heading -->

<!-- wp:buttons -->
<div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"quaternary"} -->
<div class="wp-block-button"><a class="wp-block-button__link has-quaternary-background-color has-background">View all →</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group -->

<!-- wp:columns {"style":{"spacing":{"blockGap":"60px"}}} -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:paragraph {"textColor":"quaternary"} -->
<p class="has-quaternary-color has-text-color">★★★★★</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph -->
<p><strong>"Awesome, simply awesome!"</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">Makes this service so much easier to use, and our clients love it too.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:paragraph {"textColor":"quaternary"} -->
<p class="has-quaternary-color has-text-color">★★★★★</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph -->
<p><strong>"Second to none"</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">How I wish this product existed years ago. Could not do without it now.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:paragraph {"textColor":"quaternary"} -->
<p class="has-quaternary-color has-text-color">★★★★★</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph -->
<p><strong>"Great value for money"</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">Just give em a call, the best decision we ever made!</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group -->',
);
