import type from '../../_data/typography/typography.json';

export default {
	display1: type[ 'display-font-size' ],
	display2: type[ 'display-font-size' ],
	display3: type[ 'display-font-size' ],
	display4: type[ 'display-font-size' ],
	h1: type[ 'font-size-26' ],
	h2: type[ 'font-size-20' ],
	h3: type[ 'font-size-base' ],
	h4: type[ 'font-size-15' ],
	h5: type[ 'font-size-14' ],
	h6: type[ 'font-size-14' ],
};
