<?php
return array(
			'title'         => __( 'Get in Touch 1', 'alara' ),
			'categories'    => array( 'alara-about' ),
			'keywords'		=> array( 'about', 'media', 'image', 'button' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:media-text {"mediaLink":"' . alara_pattern_content( 'image-woman-1' ) . '","align":"","mediaType":"image","imageFill":false,"backgroundColor":"octonary"} -->
<div class="wp-block-media-text is-stacked-on-mobile has-octonary-background-color has-background"><figure class="wp-block-media-text__media"><img src="' . alara_pattern_content( 'image-woman-1' ) . '" alt=""/></figure><div class="wp-block-media-text__content"><!-- wp:heading -->
<h2 id="want-to-learn-more-1">Want to learn more?</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">Lorem ipsum dolor sit amet consectetur adipiscing elit duis nibh sodales lectus, fusce nunc tellus auctor aenean risus nullam iaculis magna rutrum.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":40} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons -->
<div class="wp-block-buttons"><!-- wp:button {"textColor":"white","gradient":"foreground-tertiary-button","className":"is-style-fill"} -->
<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-white-color has-foreground-tertiary-button-gradient-background has-text-color has-background"><strong>Get in Touch →</strong></a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div></div>
<!-- /wp:media-text -->',
);
