<?php
return array(
			'title'         => __( 'Feature Comparison 2', 'alara' ),
			'categories'    => array( 'alara-features' ),
			'keywords'		=> array( 'about', 'feature', 'button' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:heading -->
<h2 id="take-your-business-to-the-next-level">Take your business to the next level</h2>
<!-- /wp:heading --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"gradient":"background-and-secondary"} -->
<div class="wp-block-group has-background-and-secondary-gradient-background has-background"><!-- wp:paragraph -->
<p><strong>Feature One</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">Service integration made easy.</p>
<!-- /wp:paragraph -->

<!-- wp:image {"linkDestination":"none"} -->
<figure class="wp-block-image"><img src="' . alara_pattern_content( 'image-camera-lens-2' ) . '" alt=""/></figure>
<!-- /wp:image --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"gradient":"background-and-secondary"} -->
<div class="wp-block-group has-background-and-secondary-gradient-background has-background"><!-- wp:paragraph -->
<p><strong>Feature Two</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">View all insights in one place.</p>
<!-- /wp:paragraph -->

<!-- wp:image {"linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="' . alara_pattern_content( 'image-camera-lens' ) . '" alt=""/></figure>
<!-- /wp:image --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"gradient":"background-and-secondary"} -->
<div class="wp-block-group has-background-and-secondary-gradient-background has-background"><!-- wp:paragraph -->
<p><strong>Feature Three</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">All information is readily available.</p>
<!-- /wp:paragraph -->

<!-- wp:image {"linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="' . alara_pattern_content( 'image-camera-lens' ) . '" alt=""/></figure>
<!-- /wp:image --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"gradient":"background-and-secondary"} -->
<div class="wp-block-group has-background-and-secondary-gradient-background has-background"><!-- wp:paragraph -->
<p><strong>Feature Four</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"fontSize":"small"} -->
<p class="has-small-font-size">Regular automatic product updates.</p>
<!-- /wp:paragraph -->

<!-- wp:image {"linkDestination":"none"} -->
<figure class="wp-block-image size-full"><img src="' . alara_pattern_content( 'image-camera-lens-2' ) . '" alt=""/></figure>
<!-- /wp:image --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
