<?php
return array(
			'title'         => __( 'Call to Action 1', 'alara' ),
			'categories'    => array( 'alara-cta' ),
			'keywords'		=> array( 'about', 'feature', 'button' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:group {"backgroundColor":"quinary","layout":{"type":"flex","allowOrientation":false,"justifyContent":"space-between"}} -->
<div class="wp-block-group has-quinary-background-color has-background"><!-- wp:group -->
<div class="wp-block-group"><!-- wp:heading {"textColor":"background"} -->
<h2 class="has-background-color has-text-color" id="see-how-it-works">See how it works</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"textColor":"background"} -->
<p class="has-background-color has-text-color">Check out our awesome product today!</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":32} -->
<div style="height:32px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons -->
<div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"foreground"} -->
<div class="wp-block-button"><a class="wp-block-button__link has-foreground-background-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group -->

<!-- wp:group -->
<div class="wp-block-group"><!-- wp:image {"align":"center","linkDestination":"none"} -->
<div class="wp-block-image"><figure class="aligncenter"><img src="' . alara_pattern_content( 'image-camera-lens-medium-2' ) . '" alt=""/></figure></div>
<!-- /wp:image -->

<!-- wp:group {"className":"is-style-no-block-gap","layout":{"type":"flex","allowOrientation":false}} -->
<div class="wp-block-group is-style-no-block-gap"><!-- wp:list {"textColor":"foreground","className":"is-style-check","fontSize":"smaller"} -->
<ul class="is-style-check has-foreground-color has-text-color has-smaller-font-size"><li><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-white-color"><strong>Integration</strong></mark></li></ul>
<!-- /wp:list -->

<!-- wp:list {"textColor":"foreground","className":"is-style-check","fontSize":"smaller"} -->
<ul class="is-style-check has-foreground-color has-text-color has-smaller-font-size"><li><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-white-color"><strong>Insights</strong></mark></li></ul>
<!-- /wp:list -->

<!-- wp:list {"textColor":"foreground","className":"is-style-check","fontSize":"smaller"} -->
<ul class="is-style-check has-foreground-color has-text-color has-smaller-font-size"><li><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-white-color"><strong>Information</strong></mark></li></ul>
<!-- /wp:list --></div>
<!-- /wp:group --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->',
);
