<!-- wp:template-part {"slug":"header","tagName":"header"} /-->

<!-- wp:group {"tagName":"main","className":"site-content single"} -->
<main id="primary" class="wp-block-group site-content single"><!-- wp:group {"layout":{"inherit":true}} -->
<div class="wp-block-group"><!-- wp:post-title {"textAlign":"center","level":1} /--></div>
<!-- /wp:group -->

<!-- wp:post-content {"layout":{"inherit":true},"className":"is-style-reading-width"} /-->

<!-- wp:group {"style":{"spacing":{"padding":{"top":"1em","bottom":"0.5em"}}},"className":"is-style-reading-width"} -->
<div class="wp-block-group is-style-reading-width" style="padding-top:1em;padding-bottom:0.5em"><!-- wp:separator {"color":"septenary","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-septenary-background-color has-septenary-color is-style-wide"/>
<!-- /wp:separator --></div>
<!-- /wp:group -->

<!-- wp:group {"style":{"spacing":{"padding":{"top":"0.5em","bottom":"1em"}}},"layout":{"inherit":true},"className":"is-style-reading-width"} -->
<div class="wp-block-group is-style-reading-width" style="padding-top:0.5em;padding-bottom:1em"><!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:post-author {"showAvatar":false,"showBio":false} /-->

<!-- wp:post-date /--></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:post-terms {"term":"category"} /-->

<!-- wp:post-terms {"term":"post_tag"} /--></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group -->

<!-- wp:group {"layout":{"inherit":true},"className":"is-style-reading-width"} -->
<div class="wp-block-group is-style-reading-width"><!-- wp:post-comments {"className":"is-style-hide-nocomments"} /--></div>
<!-- /wp:group --></main>
<!-- /wp:group -->


<!-- wp:template-part {"slug":"footer","tagName":"footer"} /-->