<?php
return array(
	'title'			=> __( 'Pricing Table 2', 'alara' ),
	'categories'	=> array( 'alara-pricing-tables' ),
	'keywords'		=> array( 'column' ),
	'viewportWidth'	=> 1280,
	'content'		=> '<!-- wp:columns {"align":"","style":{"spacing":{"blockGap":"0px"}}} -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"bottom":"50px","top":"20px","right":"30px","left":"30px"}}},"backgroundColor":"octonary","textColor":"foreground"} -->
<div class="wp-block-column has-foreground-color has-octonary-background-color has-text-color has-background" style="padding-top:20px;padding-right:30px;padding-bottom:50px;padding-left:30px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"10px","right":"10px","bottom":"20px","left":"10px"}}},"layout":{"type":"flex","justifyContent":"space-between"}} -->
<div class="wp-block-group" style="padding-top:10px;padding-right:10px;padding-bottom:20px;padding-left:10px"><!-- wp:heading -->
<h2 id="one">One</h2>
<!-- /wp:heading -->

<!-- wp:group -->
<div class="wp-block-group"><!-- wp:paragraph {"align":"right"} -->
<p class="has-text-align-right">$9</p>
<!-- /wp:paragraph -->

<!-- wp:separator {"color":"primary","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-primary-background-color has-primary-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:paragraph {"fontSize":"smaller"} -->
<p class="has-smaller-font-size"><em>month</em></p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->

<!-- wp:separator {"color":"primary","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-primary-background-color has-primary-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:spacer {"height":10} -->
<div style="height:10px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle"} -->
<ul class="is-style-circle">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"secondary","textColor":"foreground","width":100,"fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size has-small-font-size"><a class="wp-block-button__link has-foreground-color has-secondary-background-color has-text-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"20px","right":"30px","bottom":"50px","left":"30px"}}},"backgroundColor":"secondary","textColor":"foreground"} -->
<div class="wp-block-column has-foreground-color has-secondary-background-color has-text-color has-background" style="padding-top:20px;padding-right:30px;padding-bottom:50px;padding-left:30px"><!-- wp:group {"style":{"spacing":{"padding":{"right":"10px","left":"10px","top":"10px","bottom":"20px"}}},"layout":{"type":"flex","justifyContent":"space-between"}} -->
<div class="wp-block-group" style="padding-top:10px;padding-right:10px;padding-bottom:20px;padding-left:10px"><!-- wp:heading -->
<h2 id="one">Two</h2>
<!-- /wp:heading -->

<!-- wp:group -->
<div class="wp-block-group"><!-- wp:paragraph {"align":"right"} -->
<p class="has-text-align-right">$14</p>
<!-- /wp:paragraph -->

<!-- wp:separator {"color":"septenary","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-septenary-background-color has-septenary-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:paragraph {"fontSize":"smaller"} -->
<p class="has-smaller-font-size"><em>month</em></p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->

<!-- wp:separator {"color":"septenary","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-septenary-background-color has-septenary-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:spacer {"height":10} -->
<div style="height:10px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle"} -->
<ul class="is-style-circle">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"width":100,"fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size has-small-font-size"><a class="wp-block-button__link">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"20px","right":"30px","bottom":"50px","left":"30px"}}},"backgroundColor":"primary","textColor":"foreground"} -->
<div class="wp-block-column has-foreground-color has-primary-background-color has-text-color has-background" style="padding-top:20px;padding-right:30px;padding-bottom:50px;padding-left:30px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"10px","right":"10px","bottom":"20px","left":"10px"}}},"layout":{"type":"flex","justifyContent":"space-between"}} -->
<div class="wp-block-group" style="padding-top:10px;padding-right:10px;padding-bottom:20px;padding-left:10px"><!-- wp:heading -->
<h2 id="one">Three</h2>
<!-- /wp:heading -->

<!-- wp:group -->
<div class="wp-block-group"><!-- wp:paragraph {"align":"right"} -->
<p class="has-text-align-right">$19</p>
<!-- /wp:paragraph -->

<!-- wp:separator {"color":"background","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-background-background-color has-background-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:paragraph {"fontSize":"smaller"} -->
<p class="has-smaller-font-size"><em>month</em></p>
<!-- /wp:paragraph --></div>
<!-- /wp:group --></div>
<!-- /wp:group -->

<!-- wp:separator {"color":"background","className":"is-style-wide"} -->
<hr class="wp-block-separator has-text-color has-background has-background-background-color has-background-color is-style-wide"/>
<!-- /wp:separator -->

<!-- wp:spacer {"height":10} -->
<div style="height:10px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle"} -->
<ul class="is-style-circle">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"foreground","textColor":"background","width":100,"fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size has-small-font-size"><a class="wp-block-button__link has-background-color has-foreground-background-color has-text-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
