<?php
return array(
	'title'			=> __( 'Pricing Table 3', 'alara' ),
	'categories'	=> array( 'alara-pricing-tables' ),
	'keywords'		=> array( 'column' ),
	'viewportWidth'	=> 1280,
	'content'		=> '<!-- wp:columns {"align":""} -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"bottom":"50px"}}},"gradient":"bronze"} -->
<div class="wp-block-column has-bronze-gradient-background has-background" style="padding-bottom:50px"><!-- wp:heading {"textAlign":"center"} -->
<h2 class="has-text-align-center" id="bronze">Bronze</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$9</strong> <sub>/ month</sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"octonary"} -->
<ul class="has-octonary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"foreground","textColor":"background","className":"is-style-fill"} -->
<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-background-color has-foreground-background-color has-text-color has-background">SUBSCRIBE</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"bottom":"50px"}}},"gradient":"silver"} -->
<div class="wp-block-column has-silver-gradient-background has-background" style="padding-bottom:50px"><!-- wp:heading {"textAlign":"center"} -->
<h2 class="has-text-align-center" id="silver">Silver</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$14</strong> <sub>/ month</sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"octonary"} -->
<ul class="has-octonary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"foreground","textColor":"background","className":"is-style-fill"} -->
<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-background-color has-foreground-background-color has-text-color has-background">SUBSCRIBE</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"bottom":"50px"}}},"gradient":"gold"} -->
<div class="wp-block-column has-gold-gradient-background has-background" style="padding-bottom:50px"><!-- wp:heading {"textAlign":"center"} -->
<h2 class="has-text-align-center" id="gold">Gold</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$19</strong> <sub>/ month</sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"octonary"} -->
<ul class="has-octonary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"foreground","textColor":"background","className":"is-style-fill"} -->
<div class="wp-block-button is-style-fill"><a class="wp-block-button__link has-background-color has-foreground-background-color has-text-color has-background">SUBSCRIBE</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
